summaryrefslogtreecommitdiff
path: root/websvcs
diff options
context:
space:
mode:
authorbrunsch <brunsch@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2000-05-02 17:13:29 +0000
committerbrunsch <brunsch@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2000-05-02 17:13:29 +0000
commit21b3335a203055c4f0510bbb286c15dbe237c677 (patch)
treea1443cab60988384ec76d8b8f3e06a90d0ced6f9 /websvcs
parent68442232059215b551a78436b4ab3a44cf33b574 (diff)
downloadATCD-21b3335a203055c4f0510bbb286c15dbe237c677.tar.gz
ChangeLogTag:Tue May 2 10:05:21 2000 Darrell Brunsch <brunsch@uci.edu>
Diffstat (limited to 'websvcs')
-rw-r--r--websvcs/lib/URL_Addr.cpp45
-rw-r--r--websvcs/lib/URL_Addr.h14
-rw-r--r--websvcs/lib/URL_Addr.i26
-rw-r--r--websvcs/lib/websvcs.dsp12
4 files changed, 52 insertions, 45 deletions
diff --git a/websvcs/lib/URL_Addr.cpp b/websvcs/lib/URL_Addr.cpp
index 43cd57389c2..14abe7661d0 100644
--- a/websvcs/lib/URL_Addr.cpp
+++ b/websvcs/lib/URL_Addr.cpp
@@ -1,6 +1,5 @@
// $Id$
-#define ACE_WEBSVCS_BUILD_DLL
#include "URL_Addr.h"
#if !defined (__ACE_INLINE__)
@@ -316,8 +315,8 @@ ACE_HTTP_Addr::url_size (int flags) const
inline int
path_copy (const ACE_TCHAR *begin,
- const ACE_TCHAR */* end */,
- const ACE_TCHAR *& target,
+ const ACE_TCHAR * /* end */,
+ ACE_TCHAR *& target,
const ACE_TCHAR *src)
{
// Copy one character at a time, if we find a /../ we go back to the
@@ -449,7 +448,7 @@ ACE_HTTP_Addr::string_to_addr (const ACE_TCHAR *address)
if (this->ACE_URL_Addr::string_to_addr (address) != 0)
return -1;
- ACE_TCHAR *string = address;
+ const ACE_TCHAR *string = address;
string += http_size;
string += 2; // == strlen ("//");
@@ -537,7 +536,7 @@ ACE_HTTP_Addr::accept (ACE_URL_Addr_Visitor *visitor)
ACE_FTP_Addr::ACE_FTP_Addr (void)
: user_ (0),
- passwd_ (0),
+ password_ (0),
hostname_ (0),
path_ (0)
{
@@ -546,19 +545,19 @@ ACE_FTP_Addr::ACE_FTP_Addr (void)
ACE_FTP_Addr::ACE_FTP_Addr (const ACE_TCHAR *host_name,
const ACE_TCHAR *path,
const ACE_TCHAR *user,
- const ACE_TCHAR *passwd)
+ const ACE_TCHAR *password)
: user_ (0),
- passwd_ (0),
+ password_ (0),
hostname_ (0),
path_ (0)
{
- this->set (host_name, path, user, passwd);
+ this->set (host_name, path, user, password);
}
ACE_FTP_Addr::ACE_FTP_Addr (const ACE_FTP_Addr& addr)
: ACE_URL_Addr (),
user_ (0),
- passwd_ (0),
+ password_ (0),
hostname_ (0),
path_ (0)
{
@@ -574,7 +573,7 @@ int
ACE_FTP_Addr::set (const ACE_TCHAR *host_name,
const ACE_TCHAR *path,
const ACE_TCHAR *user,
- const ACE_TCHAR *passwd)
+ const ACE_TCHAR *password)
{
if (host_name == 0 || path == 0)
return -1;
@@ -585,10 +584,10 @@ ACE_FTP_Addr::set (const ACE_TCHAR *host_name,
ACE_ALLOCATOR_RETURN (this->user_, ACE_OS::strdup (user), -1);
else
this->user_ = 0;
- if (this->passwd_ != 0)
- ACE_ALLOCATOR_RETURN (this->passwd_, ACE_OS::strdup (passwd), -1);
+ if (this->password_ != 0)
+ ACE_ALLOCATOR_RETURN (this->password_, ACE_OS::strdup (password), -1);
else
- this->passwd_ = 0;
+ this->password_ = 0;
size_t size = this->url_size (1);
@@ -615,10 +614,10 @@ ACE_FTP_Addr::set (const ACE_FTP_Addr& addr)
ACE_ALLOCATOR_RETURN (this->user_, ACE_OS::strdup (addr.user_), -1);
else
this->user_ = 0;
- if (addr.passwd_ != 0)
- ACE_ALLOCATOR_RETURN (this->passwd_, ACE_OS::strdup (addr.passwd_), -1);
+ if (addr.password_ != 0)
+ ACE_ALLOCATOR_RETURN (this->password_, ACE_OS::strdup (addr.password_), -1);
else
- this->passwd_ = 0;
+ this->password_ = 0;
return 0;
}
@@ -631,8 +630,8 @@ ACE_FTP_Addr::clear (void)
ACE_OS::free (this->path_);
if (this->user_ != 0)
ACE_OS::free (this->user_);
- if (this->passwd_ != 0)
- ACE_OS::free (this->passwd_);
+ if (this->password_ != 0)
+ ACE_OS::free (this->password_);
}
size_t
@@ -646,7 +645,7 @@ ACE_FTP_Addr::url_size (int flags) const
size_t chars =
+ (this->user_?ACE_OS::strlen (this->path_):0)
- + (this->passwd_?ACE_OS::strlen (this->passwd_):0)
+ + (this->password_?ACE_OS::strlen (this->password_):0)
+ (this->path_?ACE_OS::strlen (this->path_):0);
if (flags == 0)
@@ -677,9 +676,9 @@ ACE_FTP_Addr::addr_to_string (ACE_TCHAR *buffer,
{
n += ACE_OS::sprintf (buffer + n, "%s", this->user_);
}
- if (this->passwd_ != 0)
+ if (this->password_ != 0)
{
- n += ACE_OS::sprintf (buffer + n, ":%s", this->passwd_);
+ n += ACE_OS::sprintf (buffer + n, ":%s", this->password_);
}
if (this->user_ != 0)
@@ -714,7 +713,7 @@ ACE_FTP_Addr::string_to_addr (const ACE_TCHAR *address)
this->clear ();
this->hostname_ = 0;
this->user_ = 0;
- this->passwd_ = 0;
+ this->password_ = 0;
this->path_ = 0;
// Save the original URL....
@@ -750,7 +749,7 @@ ACE_FTP_Addr::string_to_addr (const ACE_TCHAR *address)
{
pass_start[0] = '\0';
pass_start++;
- ACE_ALLOCATOR_RETURN (this->passwd_,
+ ACE_ALLOCATOR_RETURN (this->password_,
ACE_OS::strdup (pass_start),
-1);
}
diff --git a/websvcs/lib/URL_Addr.i b/websvcs/lib/URL_Addr.i
index be329668408..5e4f83453f7 100644
--- a/websvcs/lib/URL_Addr.i
+++ b/websvcs/lib/URL_Addr.i
@@ -19,14 +19,14 @@ ACE_URL_Addr::operator= (const ACE_URL_Addr& address)
return *this;
}
-ACE_INLINE LPCTSTR
+ACE_INLINE const ACE_TCHAR *
ACE_URL_Addr::get_url (void) const
{
return this->url_;
}
ACE_INLINE void
-ACE_URL_Addr::set_url (LPTSTR url)
+ACE_URL_Addr::set_url (ACE_TCHAR *url)
{
this->url_ = url;
}
@@ -55,7 +55,7 @@ ACE_HTTP_Addr::get_inet_address (void) const
return ACE_INET_Addr (this->port_number_, this->hostname_);
}
-ACE_INLINE LPCTSTR
+ACE_INLINE const ACE_TCHAR *
ACE_HTTP_Addr::get_hostname (void) const
{
return this->hostname_;
@@ -67,13 +67,13 @@ ACE_HTTP_Addr::get_port_number (void) const
return this->port_number_;
}
-ACE_INLINE LPCTSTR
+ACE_INLINE const ACE_TCHAR *
ACE_HTTP_Addr::get_path (void) const
{
return this->path_;
}
-ACE_INLINE LPCTSTR
+ACE_INLINE const ACE_TCHAR *
ACE_HTTP_Addr::get_query (void) const
{
return this->query_;
@@ -91,25 +91,25 @@ ACE_FTP_Addr::operator= (const ACE_FTP_Addr& rhs)
return *this;
}
-ACE_INLINE LPCTSTR
+ACE_INLINE const ACE_TCHAR *
ACE_FTP_Addr::get_user (void) const
{
return this->user_;
}
-ACE_INLINE LPCTSTR
+ACE_INLINE const ACE_TCHAR *
ACE_FTP_Addr::get_hostname (void) const
{
return this->hostname_;
}
-ACE_INLINE LPCTSTR
+ACE_INLINE const ACE_TCHAR *
ACE_FTP_Addr::get_passwd (void) const
{
- return this->passwd_;
+ return this->password_;
}
-ACE_INLINE LPCTSTR
+ACE_INLINE const ACE_TCHAR *
ACE_FTP_Addr::get_path (void) const
{
return this->path_;
@@ -133,19 +133,19 @@ ACE_Mailto_Addr::operator= (const ACE_Mailto_Addr& rhs)
return *this;
}
-ACE_INLINE LPCTSTR
+ACE_INLINE const ACE_TCHAR *
ACE_Mailto_Addr::get_user (void) const
{
return this->user_;
}
-ACE_INLINE LPCTSTR
+ACE_INLINE const ACE_TCHAR *
ACE_Mailto_Addr::get_hostname (void) const
{
return this->hostname_;
}
-ACE_INLINE LPCTSTR
+ACE_INLINE const ACE_TCHAR *
ACE_Mailto_Addr::get_headers (void) const
{
return this->headers_;
diff --git a/websvcs/lib/websvcs.dsp b/websvcs/lib/websvcs.dsp
index 54e6c7d1a3d..bc2f4ff1f30 100644
--- a/websvcs/lib/websvcs.dsp
+++ b/websvcs/lib/websvcs.dsp
@@ -43,7 +43,7 @@ RSC=rc.exe
# PROP Ignore_Export_Lib 0
# PROP Target_Dir ""
# ADD BASE CPP /nologo /MT /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_WINDOWS" /D "_MBCS" /D "_USRDLL" /D "WEBSVCS_EXPORTS" /YX /FD /c
-# ADD CPP /nologo /MD /W3 /GX /O2 /I "..\..\\" /D "NDEBUG" /D "WIN32" /D "_WINDOWS" /D "_MBCS" /D "_USRDLL" /D "WEBSVCS_EXPORTS" /D "ACE_WEBSVCS_HAS_DLL" /FD /c
+# ADD CPP /nologo /MD /W3 /GX /O2 /I "..\..\\" /D "NDEBUG" /D "WIN32" /D "_WINDOWS" /D "ACE_WEBSVCS_BUILD_DLL" /FD /c
# SUBTRACT CPP /YX
# ADD BASE MTL /nologo /D "NDEBUG" /mktyplib203 /win32
# ADD MTL /nologo /D "NDEBUG" /mktyplib203 /win32
@@ -70,7 +70,7 @@ LINK32=link.exe
# PROP Ignore_Export_Lib 0
# PROP Target_Dir ""
# ADD BASE CPP /nologo /MTd /W3 /Gm /GX /Zi /Od /D "WIN32" /D "_DEBUG" /D "_WINDOWS" /D "_MBCS" /D "_USRDLL" /D "WEBSVCS_EXPORTS" /YX /FD /c
-# ADD CPP /nologo /MDd /W3 /Gm /GX /Zi /Od /I "..\..\\" /D "_DEBUG" /D "WIN32" /D "_WINDOWS" /D "_MBCS" /D "_USRDLL" /D "WEBSVCS_EXPORTS" /D "ACE_WEBSVCS_HAS_DLL" /FD /c
+# ADD CPP /nologo /MDd /W3 /Gm /GX /Zi /Od /I "..\..\\" /D "_DEBUG" /D "WIN32" /D "_WINDOWS" /D "ACE_WEBSVCS_BUILD_DLL" /FR /FD /c
# SUBTRACT CPP /YX
# ADD BASE MTL /nologo /D "_DEBUG" /mktyplib203 /win32
# ADD MTL /nologo /D "_DEBUG" /mktyplib203 /win32
@@ -109,5 +109,13 @@ SOURCE=.\URL_Addr.h
SOURCE=.\websvcs_export.h
# End Source File
# End Group
+# Begin Group "Inline Files"
+
+# PROP Default_Filter "i"
+# Begin Source File
+
+SOURCE=.\URL_Addr.i
+# End Source File
+# End Group
# End Target
# End Project
diff --git a/websvcs/lib/URL_Addr.h b/websvcs/lib/URL_Addr.h
index aae680512e8..432b44a0f94 100644
--- a/websvcs/lib/URL_Addr.h
+++ b/websvcs/lib/URL_Addr.h
@@ -250,9 +250,9 @@ class ACE_WEBSVCS_Export ACE_FTP_Addr : public ACE_URL_Addr
//
// but the most general form is:
//
- // ftp://user:passwd@hostname/path
+ // ftp://user:password@hostname/path
//
// the [:passwd] part can be omitted too.
//
public:
ACE_FTP_Addr (void);
@@ -261,14 +261,14 @@ public:
ACE_FTP_Addr (const ACE_TCHAR *host_name,
const ACE_TCHAR *path,
const ACE_TCHAR *user = 0,
- const ACE_TCHAR *passwd = 0);
+ const ACE_TCHAR *password = 0);
// Construct an FTP URL from the host_name, the path, the username
- // and the passwd.
+ // and the password.
int set (const ACE_TCHAR *host_name,
const ACE_TCHAR *path,
const ACE_TCHAR *user = 0,
- const ACE_TCHAR *passwd = 0);
+ const ACE_TCHAR *password = 0);
// Essentially the constructor above.
ACE_FTP_Addr (const ACE_FTP_Addr &addr);
@@ -290,7 +290,7 @@ public:
// Get the username component in the URL
const ACE_TCHAR *get_passwd (void) const;
// Get the passwd component in the URL
const ACE_TCHAR *get_path (void) const;
// Get the path component in the URL
@@ -316,7 +316,7 @@ private:
private:
ACE_TCHAR *user_;
- ACE_TCHAR *passwd_;
+ ACE_TCHAR *password_;
// The login name
ACE_TCHAR *hostname_;
@@ -250,9 +250,9 @@ class ACE_WEBSVCS_Export ACE_FTP_Addr : public ACE_URL_Addr
//
- // the [:passwd] part can be omitted too.
+ // the [:password] part can be omitted too.
//
public:
@@ -290,7 +290,7 @@ public:
// Get the username component in the URL
const ACE_TCHAR *get_passwd (void) const;
- // Get the passwd component in the URL
+ // Get the password component in the URL
const ACE_TCHAR *get_path (void) const;
// Get the path component in the URL